@@ -1,26 +1,24 @@
 /* algol.h */
 
 /*----------------------------------------------------------------------
--- This file is a part of the MARST package.
+-- Copyright (C) 2000, 2001 Free Software Foundation, Inc.
 --
--- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                          Department for Applied Informatics,
---                          Moscow Aviation Institute, Moscow, Russia.
---                          All rights reserved.
+-- This file is part of GNU MARST.
 --
--- This code is free software; you can redistribute it and/or modify
+-- GNU MARST is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2 of the License, or
--- (at your option) any later version.
+-- the Free Software Foundation; either version 2, or (at your option)
+-- any later version.
 --
--- This software is distributed "as is" in the hope that it will be
--- useful, but WITHOUT ANY WARRANTY; without even the implied warranty
--- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+-- GNU MARST is distributed in the hope that it will be useful, but
+-- WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 -- General Public License for more details.
 --
 -- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
+-- along with GNU MARST; see the file COPYING. If not, write to the
+-- Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
+-- MA 02111-1307, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _ALGOL_H
@@ -36,7 +34,7 @@
 #include <string.h>
 
 typedef int bool;
-/* this type is used to represent Boolean quantities */
+/* type used to represent Boolean quantities */
 
 #define true  1
 #define false 0
@@ -52,39 +50,39 @@ struct dsa
       struct dsa *parent;
       /* pointer to DSA of calling (parent) procedure */
       struct dsa *vector[/* procedure level + 1 */ 1];
-      /* procedure display (display is a list of pointers to DSA of
-         those procedures that encloses this procedure); last entry in
-         display points to DSA of this procedure */
-      /* additional DSA members for each individual procedure are
-         located here */
+      /* procedure display (display is a list of pointers to DSA of the
+         procedures that enclose this procedure; the last display entry
+         points to DSA of this procedure itself) */
+      /* additional DSA members for each an individual procedure start
+         here */
 };
 
 struct mem
-{     /* descriptor of dynamically allocated memory block */
+{     /* descriptor of a dynamically allocated memory block */
       int size;
-      /* size of block in bytes (excluding descriptor) */
+      /* size of block in bytes (except descriptor) */
       struct mem *ptr;
-      /* pointer to previous memory block descriptor in stack */
+      /* pointer to previous memory block descriptor in the stack */
       char body[/* size */ 1];
       /* block body of size bytes long */
 };
 
 struct label
-{     /* value of label to perform global go to */
-      void *jump; /* -> jmp_buf */
-      /* pointer to environment block (jmp_buf) that defines a locus in
-         that block where label is placed */
+{     /* value of a label for performing global go to */
+      void *jump; /* jmp_buf jump; */
+      /* pointer to the environment block that defines a locus in the
+         block where the label is placed */
       int kase;
-      /* sequential number of label in the appropriate block */
+      /* sequential number of the label in the appropriate block */
 };
 
 struct arg { void *arg1, *arg2; };
 /* formal parameter descriptor (any actual parameter is passed as value
-   of struct arg type) */
+   of this type) */
 
 struct desc
-{     /* returned value descriptor (value returned by thunk routine or
-         procedure is value of struct desc type) */
+{     /* returned value descriptor (a value returned by thunk routine
+         or procedure is value of this type) */
       int lval;
       /* lvalue flag:
          0 - it is a value (assignment is NOT allowed)
@@ -117,17 +115,17 @@ struct dv
       {  int lo;
          /* lower bound of subscript */
          int up;
-         /* upper bound of subscript (if lo > up then array is empty
+         /* upper bound of subscript (if lo > up, the array is empty
             and in this case base is NULL) */
       }  d[9];
-      /* subscript bounds for each dimension (actually d[n] used) */
+      /* subscript bounds for each dimension (actually d[n] is used) */
 };
 
 extern struct mem *stack_top;
-/* pointer to memory block descriptor in the top of stack */
+/* pointer to the memory block descriptor in the top of stack */
 
 extern struct dsa *active_dsa;
-/* pointer to DSA of procedure that is running at this time */
+/* pointer to DSA of the procedure that is currently running */
 
 extern struct dsa *global_dsa;
 /* pointer to DSA that contains display of surround procedure (implicit
@@ -143,8 +141,8 @@ extern struct dsa *global_dsa;
 #define notequal(x, y)     ((x) != (y) ? true : false)
 
 /* logical operators should call arguments only once and should avoid
-   "lazy" calculations specific for the C (so use "bitwise" operators
-   instead logical ones) */
+   "lazy" calculations specific to the C language (therefore "bitwise"
+   operators are used instead logical ones) */
 
 #define equiv(x, y)        equal(x, y)
 #define impl(x, y)         or(not(x), y)
