@@ -1,26 +1,24 @@
 /* print.c */
 
 /*----------------------------------------------------------------------
--- This file is a part of the MARST package.
+-- Copyright (C) 2000, 2001 Free Software Foundation, Inc.
 --
--- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                          Department for Applied Informatics,
---                          Moscow Aviation Institute, Moscow, Russia.
---                          All rights reserved.
+-- This file is part of GNU MARST.
 --
--- This code is free software; you can redistribute it and/or modify
+-- GNU MARST is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2 of the License, or
--- (at your option) any later version.
+-- the Free Software Foundation; either version 2, or (at your option)
+-- any later version.
 --
--- This software is distributed "as is" in the hope that it will be
--- useful, but WITHOUT ANY WARRANTY; without even the implied warranty
--- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+-- GNU MARST is distributed in the hope that it will be useful, but
+-- WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 -- General Public License for more details.
 --
 -- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
+-- along with GNU MARST; see the file COPYING. If not, write to the
+-- Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
+-- MA 02111-1307, USA.
 ----------------------------------------------------------------------*/
 
 #include <assert.h>
